==> kubernetes-model-core-5.11.1-sources.jar: io/fabric8/kubernetes/api/model/PatchOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PatchOptionsFluent<A extends io.fabric8.kubernetes.api.model.PatchOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToDryRun(java.lang.Integer index,java.lang.String item);
  public A setToDryRun(java.lang.Integer index,java.lang.String item);
  public A addToDryRun(java.lang.String... items);
  public A addAllToDryRun(java.util.Collection<java.lang.String> items);
  public A removeFromDryRun(java.lang.String... items);
  public A removeAllFromDryRun(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getDryRun();
  public java.lang.String getDryRun(java.lang.Integer index);
  public java.lang.String getFirstDryRun();
  public java.lang.String getLastDryRun();
  public java.lang.String getMatchingDryRun(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingDryRun(java.util.function.Predicate<java.lang.String> predicate);
  public A withDryRun(java.util.List<java.lang.String> dryRun);
  public A withDryRun(java.lang.String... dryRun);
  public java.lang.Boolean hasDryRun();
  public A addNewDryRun(java.lang.String arg0);
  public java.lang.String getFieldManager();
  public A withFieldManager(java.lang.String fieldManager);
  public java.lang.Boolean hasFieldManager();
  
  /**
   * Method is deprecated. use withFieldManager instead.
   */
  @java.lang.Deprecated
  public A withNewFieldManager(java.lang.String arg0);
  public java.lang.Boolean getForce();
  public A withForce(java.lang.Boolean force);
  public java.lang.Boolean hasForce();
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/PatchOptionsFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PatchOptionsFluent<A extends io.fabric8.kubernetes.api.model.PatchOptionsFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getApiVersion();
  public A withApiVersion(java.lang.String apiVersion);
  public java.lang.Boolean hasApiVersion();
  
  /**
   * Method is deprecated. use withApiVersion instead.
   */
  @java.lang.Deprecated
  public A withNewApiVersion(java.lang.String arg0);
  public A addToDryRun(java.lang.Integer index,java.lang.String item);
  public A setToDryRun(java.lang.Integer index,java.lang.String item);
  public A addToDryRun(java.lang.String... items);
  public A addAllToDryRun(java.util.Collection<java.lang.String> items);
  public A removeFromDryRun(java.lang.String... items);
  public A removeAllFromDryRun(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getDryRun();
  public java.lang.String getDryRun(java.lang.Integer index);
  public java.lang.String getFirstDryRun();
  public java.lang.String getLastDryRun();
  public java.lang.String getMatchingDryRun(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingDryRun(java.util.function.Predicate<java.lang.String> predicate);
  public A withDryRun(java.util.List<java.lang.String> dryRun);
  public A withDryRun(java.lang.String... dryRun);
  public java.lang.Boolean hasDryRun();
  public A addNewDryRun(java.lang.String arg0);
  public java.lang.String getFieldManager();
  public A withFieldManager(java.lang.String fieldManager);
  public java.lang.Boolean hasFieldManager();
  
  /**
   * Method is deprecated. use withFieldManager instead.
   */
  @java.lang.Deprecated
  public A withNewFieldManager(java.lang.String arg0);
  public java.lang.String getFieldValidation();
  public A withFieldValidation(java.lang.String fieldValidation);
  public java.lang.Boolean hasFieldValidation();
  
  /**
   * Method is deprecated. use withFieldValidation instead.
   */
  @java.lang.Deprecated
  public A withNewFieldValidation(java.lang.String arg0);
  public java.lang.Boolean getForce();
  public A withForce(java.lang.Boolean force);
  public java.lang.Boolean hasForce();
  public java.lang.String getKind();
  public A withKind(java.lang.String kind);
  public java.lang.Boolean hasKind();
  
  /**
   * Method is deprecated. use withKind instead.
   */
  @java.lang.Deprecated
  public A withNewKind(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
